@@ -3,6 +3,6 @@
 
 __author__ = 'Chris Lawlor'
 __email__ = 'chris.lawlor@stylecaster.com'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
-from .jenkins import Jenkins
+from .jenkins import Jenkins, Job, Build
